@@ -38,6 +38,12 @@ FAILEDOPERATION_RESTRICTEDCONCURRENCY = 'FailedOperation.RestrictedConcurrency'
 # The room does not exist.
 FAILEDOPERATION_ROOMNOTEXIST = 'FailedOperation.RoomNotExist'
 
+# The application ID does not exist.
+FAILEDOPERATION_SDKAPPIDNOTEXIST = 'FailedOperation.SdkAppIdNotExist'
+
+# The user is not in the room.
+FAILEDOPERATION_USERNOTEXIST = 'FailedOperation.UserNotExist'
+
 # Internal error.
 INTERNALERROR = 'InternalError'
 
@@ -50,6 +56,9 @@ INTERNALERROR_GETROOMCACHEIPERROR = 'InternalError.GetRoomCacheIpError'
 # Failed to get room information.
 INTERNALERROR_GETROOMFROMCACHEERROR = 'InternalError.GetRoomFromCacheError'
 
+# The user is not in the room.
+INTERNALERROR_USERNOTEXIST = 'InternalError.UserNotExist'
+
 # Parameter error.
 INVALIDPARAMETER = 'InvalidParameter'
 
@@ -62,6 +71,9 @@ INVALIDPARAMETER_ROOMID = 'InvalidParameter.RoomId'
 # `SdkAppId` is incorrect.
 INVALIDPARAMETER_SDKAPPID = 'InvalidParameter.SdkAppId'
 
+# Invalid `UserId`.
+INVALIDPARAMETER_USERID = 'InvalidParameter.UserId'
+
 # `UserIds` is incorrect.
 INVALIDPARAMETER_USERIDS = 'InvalidParameter.UserIds'
 
@@ -74,6 +86,9 @@ MISSINGPARAMETER = 'MissingParameter'
 # `AccessKey` parameter missing.
 MISSINGPARAMETER_ACCESSKEY = 'MissingParameter.AccessKey'
 
+# `AppId` missing.
+MISSINGPARAMETER_APPID = 'MissingParameter.AppId'
+
 # `Bucket` parameter missing.
 MISSINGPARAMETER_BUCKET = 'MissingParameter.Bucket'
 
